DropzoneFileInterface class abstract

Constructors

DropzoneFileInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastModified → int
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter
type → String
no setter
webkitRelativePath → String
no setter

Methods

getNative() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited